@@ -1,12 +1,9 @@
-import sys
-import os
-import StringIO
-
 from twisted.trial import unittest
 
 from twistedchecker.checkers.docstring import DocstringChecker
 
 
+
 class DocstringTestCase(unittest.TestCase):
     """
     Test for twistedchecker.checkers.docstring
